@@ -45,7 +45,7 @@ func GetAllRules() []BackwardCompatibilityRule {
 		// APIDeprecationCheck
 		newBackwardCompatibilityRule(EndpointReactivatedId, INFO, true, APIDeprecationCheck),
 		newBackwardCompatibilityRule(APIDeprecatedSunsetParseId, ERR, true, APIDeprecationCheck),
-		newBackwardCompatibilityRule(ParseErrorId, ERR, true, APIDeprecationCheck),
+		newBackwardCompatibilityRule(APIInvalidStabilityLevelId, ERR, true, APIDeprecationCheck),
 		newBackwardCompatibilityRule(APISunsetDateTooSmallId, ERR, true, APIDeprecationCheck),
 		newBackwardCompatibilityRule(EndpointDeprecatedId, INFO, true, APIDeprecationCheck),
 		// APIRemovedCheck
@@ -218,6 +218,7 @@ func GetAllRules() []BackwardCompatibilityRule {
 		newBackwardCompatibilityRule(RequestPropertyPatternChangedId, WARN, true, RequestPropertyPatternUpdatedCheck),
 		// RequestPropertyRequiredUpdatedCheck
 		newBackwardCompatibilityRule(RequestPropertyBecameRequiredId, ERR, true, RequestPropertyRequiredUpdatedCheck),
+		newBackwardCompatibilityRule(RequestPropertyBecameRequiredWithDefaultId, INFO, true, RequestPropertyRequiredUpdatedCheck),
 		newBackwardCompatibilityRule(RequestPropertyBecameOptionalId, INFO, true, RequestPropertyRequiredUpdatedCheck),
 		// RequestPropertyTypeChangedCheck
 		newBackwardCompatibilityRule(RequestBodyTypeChangedId, ERR, true, RequestPropertyTypeChangedCheck),
@@ -225,6 +226,7 @@ func GetAllRules() []BackwardCompatibilityRule {
 		// RequestPropertyUpdatedCheck
 		newBackwardCompatibilityRule(RequestPropertyRemovedId, WARN, true, RequestPropertyUpdatedCheck),
 		newBackwardCompatibilityRule(NewRequiredRequestPropertyId, ERR, true, RequestPropertyUpdatedCheck),
+		newBackwardCompatibilityRule(NewRequiredRequestPropertyWithDefaultId, INFO, true, RequestPropertyUpdatedCheck),
 		newBackwardCompatibilityRule(NewOptionalRequestPropertyId, INFO, true, RequestPropertyUpdatedCheck),
 		// RequestPropertyWriteOnlyReadOnlyCheck
 		newBackwardCompatibilityRule(RequestOptionalPropertyBecameNonWriteOnlyCheckId, INFO, true, RequestPropertyWriteOnlyReadOnlyCheck),
@@ -383,6 +385,15 @@ func GetOptionalRules() []BackwardCompatibilityRule {
 	return result
 }
 
+func GetOptionalRuleIds() []string {
+
+	result := []string{}
+	for _, rule := range GetOptionalRules() {
+		result = append(result, rule.Id)
+	}
+	return result
+}
+
 func GetRequiredRules() []BackwardCompatibilityRule {
 
 	result := []BackwardCompatibilityRule{}
