@@ -21,14 +21,15 @@ type ChangelogFlags struct {
 	excludeElements          []string
 	includeChecks            []string
 	failOn                   string
+	level                    string
 	flattenAllOf             bool
 	flattenParams            bool
 	insensitiveHeaders       bool
 	lang                     string
 	errIgnoreFile            string
 	warnIgnoreFile           string
-	deprecationDaysBeta      int
-	deprecationDaysStable    int
+	deprecationDaysBeta      uint
+	deprecationDaysStable    uint
 	color                    string
 }
 
@@ -77,11 +78,11 @@ func (flags *ChangelogFlags) getIncludeChecks() []string {
 	return flags.includeChecks
 }
 
-func (flags *ChangelogFlags) getDeprecationDaysBeta() int {
+func (flags *ChangelogFlags) getDeprecationDaysBeta() uint {
 	return flags.deprecationDaysBeta
 }
 
-func (flags *ChangelogFlags) getDeprecationDaysStable() int {
+func (flags *ChangelogFlags) getDeprecationDaysStable() uint {
 	return flags.deprecationDaysStable
 }
 
@@ -109,6 +110,10 @@ func (flags *ChangelogFlags) getFailOn() string {
 	return flags.failOn
 }
 
+func (flags *ChangelogFlags) getLevel() string {
+	return flags.level
+}
+
 func (flags *ChangelogFlags) getFailOnDiff() bool {
 	return false
 }
@@ -185,6 +190,10 @@ func (flags *ChangelogFlags) refLang() *string {
 	return &flags.lang
 }
 
+func (flags *ChangelogFlags) refFormat() *string {
+	return &flags.format
+}
+
 func (flags *ChangelogFlags) refErrIgnoreFile() *string {
 	return &flags.errIgnoreFile
 }
@@ -197,11 +206,11 @@ func (flags *ChangelogFlags) refIncludeChecks() *[]string {
 	return &flags.includeChecks
 }
 
-func (flags *ChangelogFlags) refDeprecationDaysBeta() *int {
+func (flags *ChangelogFlags) refDeprecationDaysBeta() *uint {
 	return &flags.deprecationDaysBeta
 }
 
-func (flags *ChangelogFlags) refDeprecationDaysStable() *int {
+func (flags *ChangelogFlags) refDeprecationDaysStable() *uint {
 	return &flags.deprecationDaysStable
 }
 
