@@ -117,10 +117,6 @@ func Test_BasicBreakingChanges(t *testing.T) {
 	require.Zero(t, internal.Run(cmdToArgs("oasdiff breaking ../data/openapi-test1.yaml ../data/openapi-test3.yaml"), io.Discard, io.Discard))
 }
 
-func Test_BreakingChangesInvalidFormat(t *testing.T) {
-	require.Equal(t, 100, internal.Run(cmdToArgs("oasdiff breaking ../data/openapi-test1.yaml ../data/openapi-test3.yaml --format html"), io.Discard, io.Discard))
-}
-
 func Test_BreakingChangesYaml(t *testing.T) {
 	var stdout bytes.Buffer
 	require.Zero(t, internal.Run(cmdToArgs("oasdiff breaking ../data/openapi-test1.yaml ../data/openapi-test3.yaml --format yaml"), &stdout, io.Discard))
@@ -281,6 +277,12 @@ func Test_BreakingChangesFlattenAllOf(t *testing.T) {
 	require.Zero(t, internal.Run(cmdToArgs("oasdiff breaking ../data/allof/simple.yaml ../data/allof/revision.yaml --flatten-allof --fail-on ERR"), io.Discard, io.Discard))
 }
 
+func Test_BreakingChangesInvalidDeprecationDays(t *testing.T) {
+	var stderr bytes.Buffer
+	require.Equal(t, 100, internal.Run(cmdToArgs("oasdiff breaking ../data/deprecation/base.yaml ../data/deprecation/deprecated-with-sunset.yaml --deprecation-days-stable=-1"), io.Discard, &stderr))
+	require.Equal(t, "Error: invalid argument \"-1\" for \"--deprecation-days-stable\" flag: strconv.ParseUint: parsing \"-1\": invalid syntax\n", stderr.String())
+}
+
 func Test_BreakingChangesFlattenCommonParams(t *testing.T) {
 	require.Zero(t, internal.Run(cmdToArgs("oasdiff breaking ../data/common-params/params_in_path.yaml ../data/common-params/params_in_op.yaml --flatten-params --fail-on ERR"), io.Discard, io.Discard))
 }
@@ -324,3 +326,17 @@ func Test_InvalidEnumValue(t *testing.T) {
 	require.Equal(t, `Error: invalid argument "xxx" for "-e, --exclude-elements" flag: xxx is not one of the allowed values: description, endpoints, examples, extensions, summary, or title
 `, stderr.String())
 }
+
+// The behavior of max-circular-dep (which is mapped to CircularReferenceCounter in kin-openapi) is unclear
+// All we know is that if a user gets this error, they should increase the value of max-circular-dep
+// See https://github.com/getkin/kin-openapi/issues/916
+func Test_MaxCircularInsufficient(t *testing.T) {
+	var stderr bytes.Buffer
+	require.Equal(t, 102, internal.Run(cmdToArgs("oasdiff diff ../data/circular3.yaml ../data/circular3.yaml --max-circular-dep=0"), io.Discard, &stderr))
+	require.Contains(t, stderr.String(), "Error: failed to load base spec from \"../data/circular3.yaml\": kin-openapi bug found: circular schema reference not handled with")
+}
+
+// Increasing max-circular-dep to 2 is enough to handle the circular reference
+func Test_MaxCircularSufficient(t *testing.T) {
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff diff ../data/circular3.yaml ../data/circular3.yaml --max-circular-dep=2"), io.Discard, io.Discard))
+}
